/*
 *  Copyright (C) 2006-2009  Ronald Blankendaal
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
package org.dbgl.gui;

import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.net.Socket;
import java.net.UnknownHostException;
import java.sql.SQLException;
import org.eclipse.swt.widgets.Shell;
import org.dbgl.db.Database;
import org.dbgl.model.DosboxVersion;
import org.dbgl.model.Settings;
import org.dbgl.util.FileUtils;


public final class SendToProfile extends Shell {

    private static final String LOCALHOST = "localhost";


    public static void main(final String args[]) {
        if (args.length < 1) {
            System.out.println(Settings.getInstance().msg("external.notice.addcmdusage"));
            System.exit(1);
        }

        try {

            Settings settings = Settings.getInstance();
            Socket socket = new Socket(LOCALHOST, settings.getIntValue("communication", "port"));
            new PrintWriter(socket.getOutputStream(), true).println("sendtoprofile " + args[0]);
            socket.close();

        } catch (UnknownHostException e) {
            e.printStackTrace();
            System.exit(1);
        } catch (IOException e) {
            openDialogMyself(args[0]);
        }
    }

    private static void openDialogMyself(final String file) {
        Database dbase = Database.getInstance();

        Shell shell = new Shell();
        shell.setMinimized(true);
        shell.open();

        try {
            java.util.List<DosboxVersion> dbversionsList = dbase.readDosboxVersionsList();
            if (DosboxVersion.findDefault(dbversionsList) == -1) {
                GeneralPurposeDialogs.infoMessage(shell, Settings.getInstance().msg("dialog.main.required.defaultdosboxversion"));
                try {
                    dbase.shutdown();
                } catch (SQLException e) {
                    // nothing we can do
                }
                return;
            }

            if (FileUtils.isGamePackArchiveFile(file)) {
                ImportDialog importDialog = new ImportDialog(shell, dbversionsList, new File(file));
                importDialog.open();
            } else {
	            EditProfileDialog editProfDialog = new EditProfileDialog(shell);
	            editProfDialog.sendToProfile(file);
	            editProfDialog.open();
            }
        } catch (SQLException e1) {
            GeneralPurposeDialogs.warningMessage(shell, e1.getMessage());
        }

        try {
            dbase.shutdown();
        } catch (SQLException e) {
            // nothing we can do
        }
    }
}
